Coverage report

File |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | ---
src / sgn_gwframe / base.py |  | 6 | 0 | 0 |  | 100.0%
src / sgn_gwframe / sinks / frame.py |  | 178 | 18 | 2 |  | 89.9%
src / sgn_gwframe / sources / frame.py |  | 125 | 5 | 2 |  | 96.0%
src / sgn_gwframe / sources / framewatch.py |  | 221 | 14 | 5 |  | 93.7%
Total |  | 530 | 37 | 9 |  | 93.0%

No items found using the specified filter.